# rmm-tools

Two main components:
1. A `util` directory with a number of hopefully useful utility functions and classes.
2. A customer pandas accessor `df.rmm` and `series.rmm` that make a lot of pandas
operations simpler and easier. At least that seems to be the case for me.

Later version will have more details.